@@ -1,5 +1,5 @@
-#__all__ = ['guide', 'model', 'stopping_criteria', 'calculate_posteriors',
-#           'interface', 'example_loading', 'plotting', 'model_selection', 'BoundedPareto']
+# __all__ = ['guide', 'model', 'stopping_criteria', 'calculate_posteriors',
+#           'interface', 'example_loading', 'plotting', 'model_selection', 'BoundedPareto', 'Moyal']
 
 from mobster.guide_mobster import guide
 from mobster.model_mobster import model
@@ -8,3 +8,4 @@ from mobster.example_loading import *
 from mobster.plotting_mobster import *
 from mobster.stopping_criteria import *
 from mobster.BoundedPareto import *
+from mobster.Moyal import *
